# Load main library
library(hivEstimatesAccuracy)

# Define input data path
inputDataFilePath <- "d:/Drive/Projects/19. PZH/Scripts/Received/20171013/InputData/EL.csv"

# Read input data
inputData <- ReadDataFile(inputDataFilePath)

# Pre-process data
inputData <- PreProcessInputData(inputData)

# Generete missingness summary plot
PlotMissingnessSummary(inputData)

# Read adjustment specifications. Take a specific one, "Multiple imputation"
adjustmentFilePaths <- GetAdjustmentSpecFileNames()
adjustmentSpecs <- list(
  GetAdjustmentSpec(adjustmentFilePaths["Multiple Imputations"])
)

# Run diagnostic (on the first adjustment only, this is for illustration)
adjustmentSpec <- adjustmentSpecs[[1]]
diagReportFileName <- system.file(file.path("reports/diagnostic",
                                            paste0(tools::file_path_sans_ext(basename(adjustmentSpec$FileName)),
                                                   "_diagnostic.Rmd")),
                                  package = "hivEstimatesAccuracy")
params <- list(InputData = list(Table = inputData,
                               Parameters = GetParamInfoFromAdjustSpec(adjustmentSpec$Parameters,
                                                                       infoType = "value")))
CreateReport(filePath = diagReportFileName,
             format = "html_fragment",
             params = list(InputData = list(Table = inputData,
                                            Parameters = GetParamInfoFromAdjustSpec(adjustmentSpec$Parameters,
                                                                                    infoType = "value"))))

# Run adjustments
adjustedData <- RunAdjustments(data = inputData,
                               adjustmentSpecs = adjustmentSpecs)

# Take the last adjustment output as final data
finalData <- adjustedData[[length(adjustedData)]]

# Write output
outputDataFilePath <- CreateOutputFileName(inputDataFilePath,
                                           suffix = paste0("_", GetTimeStamp()))
WriteDataFile(finalData$Table, outputDataFilePath)

# Create report
reportFilePaths <- GetReportFileNames()
params <- list(AdjustedData = finalData)
reportFileName <- CreateReport(reportFilePaths["Multiple Imputations"],
                               format = "html_fragment",
                               params = params)

reportFileName <- CreateReport(reportFilePaths["Multiple Imputations"],
                               format = "html_document",
                               params = params)

reportFileName <- CreateReport(reportFilePaths["Multiple Imputations"],
                               format = "pdf_document",
                               params = params)

reportFileName <- CreateReport(reportFilePaths["Multiple Imputations"],
                               format = "word_document",
                               params = params)
